@@ -20,8 +20,8 @@
 **
 ****************************************************************************/
 
-#ifndef APPLICATION_H
-#define APPLICATION_H
+#ifndef ZEAL_CORE_APPLICATION_H
+#define ZEAL_CORE_APPLICATION_H
 
 #include <QObject>
 
@@ -29,7 +29,6 @@ class QNetworkAccessManager;
 class QNetworkReply;
 class QThread;
 
-
 namespace Zeal {
 
 namespace Registry {
@@ -44,6 +43,7 @@ class MainWindow;
 namespace Core {
 
 class Extractor;
+class FileManager;
 class Settings;
 
 class Application : public QObject
@@ -55,10 +55,13 @@ public:
 
     static Application *instance();
 
+    WidgetUi::MainWindow *mainWindow() const;
+
     QNetworkAccessManager *networkManager() const;
     Settings *settings() const;
 
     Registry::DocsetRegistry *docsetRegistry();
+    FileManager *fileManager() const;
 
 public slots:
     void executeQuery(const Registry::SearchQuery &query, bool preventActivation);
@@ -86,6 +89,8 @@ private:
 
     QNetworkAccessManager *m_networkManager = nullptr;
 
+    FileManager *m_fileManager = nullptr;
+
     QThread *m_extractorThread = nullptr;
     Extractor *m_extractor = nullptr;
 
@@ -97,4 +102,4 @@ private:
 } // namespace Core
 } // namespace Zeal
 
-#endif // APPLICATION_H
+#endif // ZEAL_CORE_APPLICATION_H
