@@ -22,6 +22,8 @@
 
 #include "settings.h"
 
+#include "filemanager.h"
+
 #include <QCoreApplication>
 #include <QDir>
 #include <QSettings>
@@ -47,6 +49,13 @@ using namespace Zeal::Core;
 Settings::Settings(QObject *parent) :
     QObject(parent)
 {
+    qRegisterMetaTypeStreamOperators<ExternalLinkPolicy>("ExternalLinkPolicy");
+
+    // Enable local storage due to https://github.com/zealdocs/zeal/issues/872.
+    QWebSettings *webSettings = QWebSettings::globalSettings();
+    webSettings->setLocalStoragePath(FileManager::cacheLocation() + QLatin1String("/localStorage"));
+    webSettings->setAttribute(QWebSettings::LocalStorageEnabled, true);
+
     load();
 }
 
@@ -81,13 +90,53 @@ void Settings::load()
     settings->endGroup();
 
     settings->beginGroup(GroupContent);
+    // Fonts
+    QWebSettings *webSettings = QWebSettings::globalSettings();
+    serifFontFamily = settings->value(QStringLiteral("serif_font_family"),
+                                      webSettings->fontFamily(QWebSettings::SerifFont)).toString();
+    sansSerifFontFamily = settings->value(QStringLiteral("sans_serif_font_family"),
+                                          webSettings->fontFamily(QWebSettings::SansSerifFont)).toString();
+    fixedFontFamily = settings->value(QStringLiteral("fixed_font_family"),
+                                      webSettings->fontFamily(QWebSettings::FixedFont)).toString();
+
+    static const QMap<QString, QWebSettings::FontFamily> fontFamilies = {
+        {QStringLiteral("sans-serif"), QWebSettings::SansSerifFont},
+        {QStringLiteral("serif"), QWebSettings::SerifFont},
+        {QStringLiteral("monospace"), QWebSettings::FixedFont}
+    };
+
+    defaultFontFamily = settings->value(QStringLiteral("default_font_family"),
+                                        QStringLiteral("serif")).toString();
+
+    // Fallback to the serif font family.
+    if (!fontFamilies.contains(defaultFontFamily)) {
+        defaultFontFamily = QStringLiteral("serif");
+    }
+
+    webSettings->setFontFamily(QWebSettings::SansSerifFont, sansSerifFontFamily);
+    webSettings->setFontFamily(QWebSettings::SerifFont, serifFontFamily);
+    webSettings->setFontFamily(QWebSettings::FixedFont, fixedFontFamily);
+
+    const QString defaultFontFamilyResolved = webSettings->fontFamily(fontFamilies.value(defaultFontFamily));
+    webSettings->setFontFamily(QWebSettings::StandardFont, defaultFontFamilyResolved);
+
+    defaultFontSize = settings->value(QStringLiteral("default_font_size"),
+                                      webSettings->fontSize(QWebSettings::DefaultFontSize)).toInt();
+    defaultFixedFontSize = settings->value(QStringLiteral("default_fixed_font_size"),
+                                           webSettings->fontSize(QWebSettings::DefaultFixedFontSize)).toInt();
     minimumFontSize = settings->value(QStringLiteral("minimum_font_size"),
-                                      QWebSettings::globalSettings()->fontSize(QWebSettings::MinimumFontSize)).toInt();
-    QWebSettings::globalSettings()->setFontSize(QWebSettings::MinimumFontSize, minimumFontSize);
+                                      webSettings->fontSize(QWebSettings::MinimumFontSize)).toInt();
+
+    webSettings->setFontSize(QWebSettings::DefaultFontSize, defaultFontSize);
+    webSettings->setFontSize(QWebSettings::DefaultFixedFontSize, defaultFixedFontSize);
+    webSettings->setFontSize(QWebSettings::MinimumFontSize, minimumFontSize);
 
     darkModeEnabled = settings->value(QStringLiteral("dark_mode"), false).toBool();
     highlightOnNavigateEnabled = settings->value(QStringLiteral("highlight_on_navigate"), true).toBool();
     customCssFile = settings->value(QStringLiteral("custom_css_file")).toString();
+    externalLinkPolicy = settings->value(QStringLiteral("external_link_policy"),
+                                         QVariant::fromValue(ExternalLinkPolicy::Ask)).value<ExternalLinkPolicy>();
+    isSmoothScrollingEnabled = settings->value(QStringLiteral("smooth_scrolling"), false).toBool();
     isAdDisabled = settings->value(QStringLiteral("disable_ad"), false).toBool();
     settings->endGroup();
 
@@ -153,10 +202,20 @@ void Settings::save()
     settings->endGroup();
 
     settings->beginGroup(GroupContent);
+    settings->setValue(QStringLiteral("default_font_family"), defaultFontFamily);
+    settings->setValue(QStringLiteral("serif_font_family"), serifFontFamily);
+    settings->setValue(QStringLiteral("sans_serif_font_family"), sansSerifFontFamily);
+    settings->setValue(QStringLiteral("fixed_font_family"), fixedFontFamily);
+
+    settings->setValue(QStringLiteral("default_font_size"), defaultFontSize);
+    settings->setValue(QStringLiteral("default_fixed_font_size"), defaultFixedFontSize);
     settings->setValue(QStringLiteral("minimum_font_size"), minimumFontSize);
+
     settings->setValue(QStringLiteral("dark_mode"), darkModeEnabled);
     settings->setValue(QStringLiteral("highlight_on_navigate"), highlightOnNavigateEnabled);
     settings->setValue(QStringLiteral("custom_css_file"), customCssFile);
+    settings->setValue(QStringLiteral("external_link_policy"), QVariant::fromValue(externalLinkPolicy));
+    settings->setValue(QStringLiteral("smooth_scrolling"), isSmoothScrollingEnabled);
     settings->setValue(QStringLiteral("disable_ad"), isAdDisabled);
     settings->endGroup();
 
@@ -254,3 +313,17 @@ QSettings *Settings::qsettings(QObject *parent)
                          QSettings::IniFormat, parent);
 #endif
 }
+
+QDataStream &operator<<(QDataStream &out, const Settings::ExternalLinkPolicy &policy)
+{
+    out << static_cast<std::underlying_type<Settings::ExternalLinkPolicy>::type>(policy);
+    return out;
+}
+
+QDataStream &operator>>(QDataStream &in, Settings::ExternalLinkPolicy &policy)
+{
+    std::underlying_type<Settings::ExternalLinkPolicy>::type value;
+    in >> value;
+    policy = static_cast<Settings::ExternalLinkPolicy>(value);
+    return in;
+}
