@@ -37,13 +37,18 @@ struct SearchResult
     QString name;
     QString type;
 
+    QString urlPath;
+    QString urlFragment;
+
     Docset *docset;
 
-    QUrl url;
+    int score;
 
     inline bool operator<(const SearchResult &other) const
     {
-        return QString::compare(name, other.name, Qt::CaseInsensitive) < 0;
+        if (score == other.score)
+            return QString::compare(name, other.name, Qt::CaseInsensitive) < 0;
+        return score > other.score;
     }
 };
 
