@@ -157,12 +157,19 @@ MainWindow::MainWindow(Core::Application *app, QWidget *parent) :
 
     setupTabBar();
 
-    QShortcut *focusSearch = new QShortcut(QStringLiteral("Ctrl+K"), this);
-    connect(focusSearch, &QShortcut::activated,
+    // Setup application wide shortcuts.
+    // Focus search bar.
+    QShortcut *shortcut = new QShortcut(QStringLiteral("Ctrl+K"), this);
+    connect(shortcut, &QShortcut::activated,
             ui->lineEdit, static_cast<void (SearchEdit::*)()>(&SearchEdit::setFocus));
 
-    QShortcut *duplicate = new QShortcut(QStringLiteral("Ctrl+Alt+T"), this);
-    connect(duplicate, &QShortcut::activated, this, [this]() { duplicateTab(m_tabBar->currentIndex()); });
+    shortcut = new QShortcut(QStringLiteral("Ctrl+L"), this);
+    connect(shortcut, &QShortcut::activated,
+            ui->lineEdit, static_cast<void (SearchEdit::*)()>(&SearchEdit::setFocus));
+
+    // Duplicate current tab.
+    shortcut = new QShortcut(QStringLiteral("Ctrl+Alt+T"), this);
+    connect(shortcut, &QShortcut::activated, this, [this]() { duplicateTab(m_tabBar->currentIndex()); });
 
     restoreGeometry(m_settings->windowGeometry);
     ui->splitter->restoreState(m_settings->verticalSplitterGeometry);
@@ -191,7 +198,7 @@ MainWindow::MainWindow(Core::Application *app, QWidget *parent) :
     if (QKeySequence(QKeySequence::Preferences).isEmpty()) {
         ui->actionPreferences->setShortcut(QStringLiteral("Ctrl+,"));
     } else {
-        ui->actionPreferences->setShortcut(QKeySequence::Quit);
+        ui->actionPreferences->setShortcut(QKeySequence::Preferences);
     }
 
     connect(ui->actionPreferences, &QAction::triggered, [this]() {
@@ -879,7 +886,7 @@ void MainWindow::applySettings()
         removeTrayIcon();
 
     // Content
-    QByteArray ba;
+    QByteArray ba = QByteArrayLiteral("body { background-color: white; }");
     if (m_settings->darkModeEnabled) {
         QScopedPointer<QFile> file(new QFile(DarkModeCssUrl));
         if (file->open(QIODevice::ReadOnly)) {
